@@ -26,7 +26,12 @@ class Consumer(BaseClient):
 
     def start(self, arguments:Dict[str, Any]=None) -> None:
         try:
-            self.channel.queue_declare(queue=self.queue, durable=1, arguments=arguments)
+            self.channel.queue_declare(
+                queue=self.queue, 
+                durable=True,
+                auto_delete=True,
+                arguments=arguments
+            )
 
             self.channel.basic_consume(
                 queue=self.queue,
